# cyanDiff - a simple auto-differentiation library
[![.github/workflows/coverage.yml](https://code.harvard.edu/CS107/team40/actions/workflows/coverage.yml/badge.svg)](https://code.harvard.edu/CS107/team40/actions/workflows/coverage.yml) [![.github/workflows/test.yml](https://code.harvard.edu/CS107/team40/actions/workflows/test.yml/badge.svg)](https://code.harvard.edu/CS107/team40/actions/workflows/test.yml)
